==> mpf-0.33.49.tar.gz: mpf-0.33.49/README.md <==
Mission Pinball Framework (mpf)
===============================

<img align="right" height="146" src="mpf-logo-200.png"/>

Let's build a pinball machine!

The Mission Pinball Framework (MPF) is an open source, cross-platform, software framework for powering real pinball
machines.

MPF is written in Python 3. It can run on Windows, Mac, and Linux using the same code and configurations.

MPF interacts with real, physical pinball machines via modern pinball controller hardware such as the Multimorphic
P-ROC or P3-ROC, FAST Pinball controllers, Open Pinball Project (OPP) open source hardware, Stern SPIKE pinball
machines, LISY controllers for Gottlieb System 1 / System 80 machines. You can also use it to power your own
custom-built machine or to update the software in existing Williams, Bally, Stern, Data East, or Gottlieb machines.

There's also an [MPF Media Controller](https://github.com/missionpinball/mpf-mc/) (based on [Kivy](http://kivy.org))
which is used to control graphics and sounds, including high-res LCD displays, classic DMDs, and modern RGB LED DMDs.

MPF is a work-in-progress that's not yet complete, though we're actively developing it and checking in several commits a
week. It's MIT licensed, actively developed by fun people, and supported by a vibrant pinball-loving community.

The MPF project homepage is here : http://missionpinball.org

[![Coverage Status](https://coveralls.io/repos/missionpinball/mpf/badge.svg?branch=dev&service=github)](https://coveralls.io/github/missionpinball/mpf?branch=dev)
[![Build Status](https://travis-ci.org/missionpinball/mpf.svg?branch=dev)](https://travis-ci.org/missionpinball/mpf)
[![Build status](https://ci.appveyor.com/api/projects/status/ir15w3bo3kq19na1?svg=true)](https://ci.appveyor.com/project/toomanybrians/mpf)
[![Code Health](https://landscape.io/github/missionpinball/mpf/dev/landscape.svg?style=flat)](https://landscape.io/github/missionpinball/mpf/dev)


Installation, Documentation, and Examples
-----------------------------------------
* Getting started tutorial : http://docs.missionpinball.org/en/latest/tutorial/
* Installation : http://docs.missionpinball.org/en/latest/install/
* User documentation : http://docs.missionpinball.org
* Developer documentation : http://developer.missionpinball.org

Support
-------
We have a user support forum at : https://groups.google.com/forum/#!forum/mpf-users

Authors & Contributing
----------------------
MPF is a labor of love awesome pinball-loving people. There's a list of authors in the AUTHORS file. We'd love for you
to join us! Even if you don't know Python well, you can help improve the documentation or write how to guides. Drop us a
line in the forum, or make a change and submit a pull request! More info [here](http://docs.missionpinball.org/en/latest/about/contributing_to_mpf.html).

License
-------
* MPF and its related projects are released under the terms of the MIT License. Please refer to the LICENSE file for details.
* Docs are Creative Commons CC BY 4.0.
* Both of these basically mean you can do anything you want with MPF and the docs, including using them for commercial
  projects. You don't have to pay us or share your changes if you don't want to. Just go make pinball!

==> mpf-0.50.0.tar.gz: mpf-0.50.0/README.md <==
Mission Pinball Framework (mpf)
===============================

<img align="right" height="146" src="mpf-logo-200.png"/>

Let's build a pinball machine!

The Mission Pinball Framework (MPF) is an open source, cross-platform, software framework for powering real pinball
machines.

MPF is written in Python 3. It can run on Windows, Mac, and Linux using the same code and configurations.

MPF interacts with real, physical pinball machines via modern pinball controller hardware such as the Multimorphic
P-ROC or P3-ROC, FAST Pinball controllers, Open Pinball Project (OPP) open source hardware, or Stern SPIKE pinball
machines. You can use it to power your own custom-built machine or to update the software in existing Williams, Bally,
Stern, or Data East machines.

There's also an [MPF Media Controller](https://github.com/missionpinball/mpf-mc/) (based on [Kivy](http://kivy.org))
which is used to control graphics and sounds, including high-res LCD displays, classic DMDs, and modern RGB LED DMDs.

MPF is a work-in-progress that's not yet complete, though we're actively developing it and checking in several commits a
week. It's MIT licensed, actively developed by fun people, and supported by a vibrant pinball-loving community.

The MPF project homepage is here : http://missionpinball.org

[![Coverage Status](https://coveralls.io/repos/missionpinball/mpf/badge.svg?branch=dev&service=github)](https://coveralls.io/github/missionpinball/mpf?branch=dev)
[![Build Status](https://travis-ci.org/missionpinball/mpf.svg?branch=dev)](https://travis-ci.org/missionpinball/mpf)
[![Build status](https://ci.appveyor.com/api/projects/status/ir15w3bo3kq19na1?svg=true)](https://ci.appveyor.com/project/toomanybrians/mpf)
[![Code Health](https://landscape.io/github/missionpinball/mpf/dev/landscape.svg?style=flat)](https://landscape.io/github/missionpinball/mpf/dev)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/1687/badge)](https://bestpractices.coreinfrastructure.org/projects/1687)


Installation, Documentation, and Examples
-----------------------------------------
* Getting started tutorial : http://docs.missionpinball.org/en/latest/tutorial/
* Installation : http://docs.missionpinball.org/en/latest/install/
* User documentation : http://docs.missionpinball.org
* Developer documentation : http://developer.missionpinball.org/

Support
-------
We have a user support forum at : https://groups.google.com/forum/#!forum/mpf-users

Authors & Contributing
----------------------
MPF is a labor of love awesome pinball-loving people. There's a list of authors in the AUTHORS file. We'd love for you
to join us! Even if you don't know Python well, you can help improve the documentation or write how to guides. Drop us a
line in the forum, or make a change and submit a pull request! More info about [Contributing Code](http://docs.missionpinball.org/en/latest/about/contributing_to_mpf.html)
and [Contributing Documentation](http://docs.missionpinball.org/en/latest/about/contributing_to_mpf_docs.html).

License
-------
* MPF and its related projects are released under the terms of the MIT License. Please refer to the LICENSE file for details.
* Docs are Creative Commons CC BY 4.0.
* Both of these basically mean you can do anything you want with MPF and the docs, including using them for commercial
  projects. You don't have to pay us or share your changes if you don't want to. Just go make pinball!
